using System;
using System.Collections;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Windows.Forms;

namespace AcmeControls
{
   public enum EditFormat
   {
      None,
      Phone
   }

	/// <summary>
	/// Summary description for TextBoxEx.
	/// </summary>
	public class TextBoxEx : System.Windows.Forms.TextBox
	{
		private EditFormat   mFormat = EditFormat.None;
      
      public TextBoxEx()
		{
		}

		protected override void OnPaint(PaintEventArgs pe)
		{
			// Calling the base class OnPaint
			base.OnPaint(pe);
		}

      private void InitializeComponent()
      {
         // 
         // TextBoxEx
         // 
      }

      // property used to set/get the format specifier
      public EditFormat Format
      {
         get
         {
            return mFormat;
         }
         set
         {
            mFormat = value;
         }
      }

      // overriding the text property to trim and
      // format the text.
      public override string Text
      {
         get
         {
            return TrimText(base.Text);
         }
         set
         {
            base.Text = FormatText(value);
         }
      }

      // private function used to trim format characters
      private string TrimText( string text )
      {
         switch( mFormat )
         {
            case EditFormat.None:
               return text;
            case EditFormat.Phone:
               return Phone.Trim(text);
         }
         return text;
      }
      // private function used to format characters.
      private string FormatText( string text )
      {
         switch( mFormat )
         {
            case EditFormat.None:
               return text;
            case EditFormat.Phone:
               return Phone.Format(text);
         }
         return text;
      }
      // Overriding the OnValidating method so we can perform custom
      // validation before raising any events.
      protected override void OnValidating( CancelEventArgs e )
      {
         switch( mFormat )
         {
         case EditFormat.None:
            e.Cancel = false;
            break;
         case EditFormat.Phone:
            if( Phone.IsValid(base.Text) == false )
            {
               MessageBox.Show("Invalid Phone Number, please enter a 10 digit number.");
               e.Cancel = true;
               base.Select(0, base.Text.Length);
            }
            else
            {
               base.Text = Phone.Format(base.Text);
               e.Cancel = false;
            }
            break;
         }
         // call the base class
         base.OnValidating(e);
      }
	}
}
