if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[FK_Players_Positions]') and OBJECTPROPERTY(id, N'IsForeignKey') = 1)
ALTER TABLE [dbo].[Players] DROP CONSTRAINT FK_Players_Positions
GO

if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[FK_Players_Teams]') and OBJECTPROPERTY(id, N'IsForeignKey') = 1)
ALTER TABLE [dbo].[Players] DROP CONSTRAINT FK_Players_Teams
GO

/****** Object:  Stored Procedure dbo.sp_getPlayersByPosition    Script Date: 12/12/2001 7:56:08 AM ******/
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[sp_getPlayersByPosition]') and OBJECTPROPERTY(id, N'IsProcedure') = 1)
drop procedure [dbo].[sp_getPlayersByPosition]
GO

/****** Object:  Table [dbo].[Players]    Script Date: 12/12/2001 7:56:08 AM ******/
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[Players]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
drop table [dbo].[Players]
GO

/****** Object:  Table [dbo].[Positions]    Script Date: 12/12/2001 7:56:08 AM ******/
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[Positions]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
drop table [dbo].[Positions]
GO

/****** Object:  Table [dbo].[Teams]    Script Date: 12/12/2001 7:56:08 AM ******/
if exists (select * from dbo.sysobjects where id = object_id(N'[dbo].[Teams]') and OBJECTPROPERTY(id, N'IsUserTable') = 1)
drop table [dbo].[Teams]
GO

/****** Object:  Table [dbo].[Positions]    Script Date: 12/12/2001 7:56:09 AM ******/
CREATE TABLE [dbo].[Positions] (
	[PositionID] [int] IDENTITY (1, 1) NOT NULL ,
	[PositionCode] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[PositionName] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL 
) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Teams]    Script Date: 12/12/2001 7:56:10 AM ******/
CREATE TABLE [dbo].[Teams] (
	[TeamID] [int] IDENTITY (1, 1) NOT NULL ,
	[TeamCity] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[TeamName] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[TeamCode] [nvarchar] (50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL 
) ON [PRIMARY]
GO

/****** Object:  Table [dbo].[Players]    Script Date: 12/12/2001 7:56:11 AM ******/
CREATE TABLE [dbo].[Players] (
	[PlayerID] [int] IDENTITY (1, 1) NOT NULL ,
	[TeamID] [int] NULL ,
	[PositionID] [int] NULL ,
	[FirstName] [nvarchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[LastName] [nvarchar] (255) COLLATE SQL_Latin1_General_CP1_CI_AS NULL ,
	[GamesPlayed] [float] NULL ,
	[PassingCompletions] [int] NULL ,
	[PassingAttempts] [int] NULL ,
	[PassingYards] [float] NULL ,
	[PassingTouchdowns] [float] NULL ,
	[Interceptions] [float] NULL ,
	[Carries] [float] NULL ,
	[RushingYards] [float] NULL ,
	[RushingTouchdowns] [float] NULL ,
	[Receptions] [float] NULL ,
	[ReceptionYards] [float] NULL ,
	[ReceptionTouchdowns] [float] NULL ,
	[TDReturn] [float] NULL ,
	[2PointConversion] [float] NULL ,
	[Fumbles] [float] NULL 
) ON [PRIMARY]
GO

ALTER TABLE [dbo].[Positions] WITH NOCHECK ADD 
	CONSTRAINT [PK_Positions] PRIMARY KEY  CLUSTERED 
	(
		[PositionID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[Teams] WITH NOCHECK ADD 
	CONSTRAINT [PK_Teams] PRIMARY KEY  CLUSTERED 
	(
		[TeamID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[Players] WITH NOCHECK ADD 
	CONSTRAINT [PK_Players] PRIMARY KEY  CLUSTERED 
	(
		[PlayerID]
	)  ON [PRIMARY] 
GO

ALTER TABLE [dbo].[Players] ADD 
	CONSTRAINT [FK_Players_Positions] FOREIGN KEY 
	(
		[PositionID]
	) REFERENCES [dbo].[Positions] (
		[PositionID]
	),
	CONSTRAINT [FK_Players_Teams] FOREIGN KEY 
	(
		[TeamID]
	) REFERENCES [dbo].[Teams] (
		[TeamID]
	)
GO

SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO

/****** Object:  Stored Procedure dbo.sp_getPlayersByPosition    Script Date: 12/12/2001 7:56:11 AM ******/
CREATE PROCEDURE sp_getPlayersByPosition(@PositionID int) AS
BEGIN
    SELECT
        Players.PlayerID,
        FirstName,
        LastName,
        Teams.TeamName,
        GamesPlayed,
        PassingCompletions,
        PassingAttempts,
        PassingYards,
        PassingTouchdowns,
        Interceptions,
        Carries,
        RushingYards,
        RushingTouchdowns,
        Receptions,
        ReceptionYards,
        ReceptionTouchdowns,
        TDReturn,
        2PointConversion,
        Fumbles
    FROM Players WITH (NOLOCK)
    INNER JOIN Teams ON Teams.TeamID = Players.TeamID
    WHERE Players.PositionID = @PositionID
ORDER BY PassingYards DESC
END


GO

SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS ON 
GO

